@@ -10,6 +10,7 @@ import redvox.api900.concat
 import redvox.common.date_time_utils as date_time_utils
 import redvox.api900.deprecation as deprecation
 import redvox.api900.lib.api900_pb2 as api900_pb2
+import redvox.api900.migrations as migrations
 import redvox.api900.reader
 import redvox.api900.reader_utils as reader_utils
 import redvox.api900.sensors.accelerometer_sensor as _accelerometer_sensor
@@ -360,7 +361,7 @@ class WrappedRedvoxPacket:
         See https://bitbucket.org/redvoxhi/redvox-data-apis/src/master/src/api900/api900.proto?at=master for a
         description of this field.
         """
-        return self._redvox_packet.api
+        return migrations.maybe_get_float(self._redvox_packet.api)
 
     def set_api(self, version: int) -> 'WrappedRedvoxPacket':
         """
@@ -647,14 +648,14 @@ class WrappedRedvoxPacket:
         See https://bitbucket.org/redvoxhi/redvox-data-apis/src/master/src/api900/api900.proto?at=master for a
         description of this field.
         """
-        return self._redvox_packet.app_file_start_timestamp_epoch_microseconds_utc
+        return migrations.maybe_get_float(self._redvox_packet.app_file_start_timestamp_epoch_microseconds_utc)
 
     def set_app_file_start_timestamp_epoch_microseconds_utc(self, time: int) -> 'WrappedRedvoxPacket':
         """
         sets the timestamp of packet creation
         :param time: time when packet was created in microseconds since utc epoch
         """
-        self._redvox_packet.app_file_start_timestamp_epoch_microseconds_utc = time
+        self._redvox_packet.app_file_start_timestamp_epoch_microseconds_utc = migrations.maybe_set_int(time)
         return self
 
     # pylint: disable=invalid-name
@@ -663,14 +664,14 @@ class WrappedRedvoxPacket:
         See https://bitbucket.org/redvoxhi/redvox-data-apis/src/master/src/api900/api900.proto?at=master for a
         description of this field.
         """
-        return self._redvox_packet.app_file_start_timestamp_machine
+        return migrations.maybe_get_float(self._redvox_packet.app_file_start_timestamp_machine)
 
     def set_app_file_start_timestamp_machine(self, time: int) -> 'WrappedRedvoxPacket':
         """
         sets the internal machine timestamp of packet creation
         :param time: time when packet was created on local machine
         """
-        self._redvox_packet.app_file_start_timestamp_machine = time
+        self._redvox_packet.app_file_start_timestamp_machine = migrations.maybe_set_int(time)
         return self
 
     # pylint: disable=invalid-name
@@ -679,7 +680,7 @@ class WrappedRedvoxPacket:
         See https://bitbucket.org/redvoxhi/redvox-data-apis/src/master/src/api900/api900.proto?at=master for a
         description of this field.
         """
-        return self._redvox_packet.server_timestamp_epoch_microseconds_utc
+        return migrations.maybe_get_float(self._redvox_packet.server_timestamp_epoch_microseconds_utc)
 
     def set_server_timestamp_epoch_microseconds_utc(self, time: int) -> 'WrappedRedvoxPacket':
         """
@@ -745,7 +746,8 @@ class WrappedRedvoxPacket:
         Returns the start timestamp of a WrappedRedvoxPacket.
         :return: The start timestamp of a WrappedRedvoxPacket.
         """
-        return self.microphone_sensor().first_sample_timestamp_epoch_microseconds_utc()
+        return migrations.maybe_get_float(
+            self.microphone_sensor().first_sample_timestamp_epoch_microseconds_utc())
 
     def duration_s(self) -> float:
         """
@@ -755,7 +757,7 @@ class WrappedRedvoxPacket:
         microphone_sensor = self.microphone_sensor()
         return len(microphone_sensor.payload_values()) / microphone_sensor.sample_rate_hz()
 
-    def end_timestamp_us_utc(self):
+    def end_timestamp_us_utc(self) -> float:
         """
         Returns the end timestamp of a WrappedRedvoxPacket.
         :return: The end timestamp of a WrappedRedvoxPacket.
@@ -778,7 +780,20 @@ class WrappedRedvoxPacket:
         :return: The mach time zero from the metadata if it exists.
         """
         try:
-            return int(self.metadata_as_dict()["machTimeZero"])
+            # First, try to extract metadata from the correct location
+            top_level_metadata: typing.Dict[str, str] = self.metadata_as_dict()
+            if "machTimeZero" in top_level_metadata:
+                return migrations.maybe_get_float(int(top_level_metadata["machTimeZero"]))
+
+            # If that fails, some Androids stored it in the Location metadata
+            location_sensor = self.location_sensor()
+            if location_sensor is not None:
+                location_metadata: typing.Dict[str, str] = location_sensor.metadata_as_dict()
+                if "machTimeZero" in location_metadata:
+                    return migrations.maybe_get_float(int(location_metadata["machTimeZero"]))
+
+            # Finally, if it hasn't been found, it's probably a really old packet that doesn't contain this field
+            return None
         except (KeyError, ValueError):
             return None
 
